==> qpc_admob-0.0.8%2B6.tar.gz: android/src/main/java/com/qpc/qpc_admob/QpcAdmobPlugin.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.app.Activity;
import android.view.Gravity;

import com.bytedance.sdk.openadsdk.TTAdConfig;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdSdk;

import java.util.Locale;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

public class QpcAdmobPlugin implements MethodCallHandler {

  private final Registrar registrar;
  private final MethodChannel channel;

  QsjRewardedVideoAdWrapper rewardedWrapper;

  TxRewardedVideoAdWrapper txRewardedVideoAdWrapper;

  public static void registerWith(Registrar registrar) {
    if (registrar.activity() == null) {
      // If a background Flutter view tries to register the plugin, there will be no activity from the registrar.
      // We stop the registering process immediately because the firebase_admob requires an activity.
      return;
    }
    final MethodChannel channel =
        new MethodChannel(registrar.messenger(), "com.qpc/qpc_admob");
    channel.setMethodCallHandler(new QpcAdmobPlugin(registrar, channel));

  }

  private QpcAdmobPlugin(Registrar registrar, MethodChannel channel) {
    this.registrar = registrar;
    this.channel = channel;


  }

  private void callInitialize(MethodCall call, Result result) {
    String appId = call.argument("appId");
    if (appId == null || appId.isEmpty()) {
      result.error("no_app_id", "a null or empty AdMob appId was provided", null);
      return;
    }

    Boolean isDebug = call.argument("isDebug");
    if(isDebug == null)


    {
      isDebug = false;
    }

    TTAdSdk.init(registrar.context(),
            new TTAdConfig.Builder()
                    .appId(appId)//测试"5001121"
                    .useTextureView(false) //使用TextureView控件播放视频,默认为SurfaceView,当有SurfaceView冲突的场景，可以使用TextureView
                    .appName("qkl")
                    .titleBarTheme(TTAdConstant.TITLE_BAR_THEME_DARK)
                    .allowShowNotify(true) //是否允许sdk展示通知栏提示
                    .allowShowPageWhenScreenLock(true) //是否在锁屏场景支持展示广告落地页
                    .debug(isDebug) //测试阶段打开，可以通过日志排查问题，上线时去除该调用
                    .directDownloadNetworkType(TTAdConstant.NETWORK_STATE_WIFI, TTAdConstant.NETWORK_STATE_3G) //允许直接下载的网络状态集合
                    .supportMultiProcess(false) //是否支持多进程，true支持
                    //.httpStack(new MyOkStack3())//自定义网络库，demo中给出了okhttp3版本的样例，其余请自行开发或者咨询工作人员。
                    .build());


    rewardedWrapper = new QsjRewardedVideoAdWrapper(registrar.activity(), channel);
    txRewardedVideoAdWrapper = new TxRewardedVideoAdWrapper(registrar.activity(),channel);

    result.success(Boolean.TRUE);
  }

  private void callLoadBannerAd(String adPlatform,Integer id, Activity activity, MethodCall call, Result result) {
    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error("no_unit_id", "a null or empty adUnitId was provided for ad id=" + id, null);
      return;
    }

    final Integer width = call.argument("width");
    final Integer height = call.argument("height");
    final String adSizeType = call.argument("adSizeType");

    if (!"AdSizeType.WidthAndHeight".equals(adSizeType)
        && !"AdSizeType.SmartBanner".equals(adSizeType)) {
      String errMsg =
          String.format(
              Locale.ENGLISH,
              "an invalid adSizeType (%s) was provided for banner id=%d",
              adSizeType,
              id);
      result.error("invalid_adsizetype", errMsg, null);
    }

    if ("AdSizeType.WidthAndHeight".equals(adSizeType) && (width <= 0 || height <= 0)) {
      String errMsg =
          String.format(
              Locale.ENGLISH,
              "an invalid AdSize (%d, %d) was provided for banner id=%d",
              width,
              height,
              id);
      result.error("invalid_adsize", errMsg, null);
    }

    Map<String, Object> targetingInfo = call.argument("targetingInfo");

    MobileAd bannerAd= null;
    if(adPlatform.equalsIgnoreCase(AdPlatformEnum.qsj.name())){
      bannerAd  = QsjMobileAd.createBanner(id,adUnitId, width,height, activity, channel);
    }else if(adPlatform.equalsIgnoreCase(AdPlatformEnum.tx.name())) {
      bannerAd  = TxMobileAd.createBanner(id,adUnitId, width,height, activity, channel);
    }else {
      result.error("load_failed_ad", "cannot supported ad platform, id=" + id, null);
      result.success(Boolean.FALSE);
      return;

    }
    if (bannerAd.status != MobileAd.Status.CREATED) {
      if (bannerAd.status == MobileAd.Status.FAILED)
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + id, null);
      else result.success(Boolean.TRUE); // The ad was already loaded.
      return;
    }
    result.success(Boolean.TRUE);
  }

  private void callLoadInterstitialAd(String adPlatform,MobileAd ad, MethodCall call, Result result) {
    if (ad.status != MobileAd.Status.CREATED) {
      if (ad.status == MobileAd.Status.FAILED)
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + ad.id, null);
      else result.success(Boolean.TRUE); // The ad was already loaded.
      return;
    }

    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error(
          "no_adunit_id", "a null or empty adUnitId was provided for ad id=" + ad.id, null);
      return;
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    ad.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }

  private void callLoadRewardedVideoAd(String adPlatform,MethodCall call, Result result) {

    String adUnitId = call.argument("adUnitId");
    String userId = call.argument("userId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error(
              "no_ad_unit_id", "a non-empty adUnitId was not provided for rewarded video", null);
      return;
    }

    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    if (targetingInfo == null) {
      result.error(
              "no_targeting_info", "a null targetingInfo object was provided for rewarded video", null);
      return;
    }

    if(adPlatform.equalsIgnoreCase(AdPlatformEnum.qsj.name())){
      callLoadQsjRewardedVideoAd(adUnitId, userId, targetingInfo,result);
    }else if(adPlatform.equalsIgnoreCase(AdPlatformEnum.tx.name())) {
      txRewardedVideoAdWrapper.load(adUnitId,userId,targetingInfo);
    }else {
      result.error("load_failed_ad", "cannot supported ad platform, adUnitId=" + adUnitId, null);
      result.success(Boolean.FALSE);
      return;

    }
  }

  private void callLoadQsjRewardedVideoAd(String adUnitId, String userId, Map<String, Object> targetingInfo,Result result) {
    if (rewardedWrapper.getStatus() != QsjRewardedVideoAdWrapper.Status.CREATED
        && rewardedWrapper.getStatus() != QsjRewardedVideoAdWrapper.Status.FAILED) {
      result.success(Boolean.TRUE); // The ad was already loading or loaded.
      return;
    }
    rewardedWrapper.load(adUnitId,userId, targetingInfo);
    result.success(Boolean.TRUE);
  }

  private void callShowAd(String adPlatform,Integer id, MethodCall call, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("ad_not_loaded", "show failed, the specified ad was not loaded id=" + id, null);
      return;
    }
    final String anchorOffset = call.argument("anchorOffset");
    final String horizontalCenterOffset = call.argument("horizontalCenterOffset");
    final String anchorType = call.argument("anchorType");
    if (anchorOffset != null) {
      ad.anchorOffset = Double.parseDouble(anchorOffset);
    }
    if (anchorType != null) {
      ad.horizontalCenterOffset = Double.parseDouble(horizontalCenterOffset);
    }
    if (anchorType != null) {
      ad.anchorType = "bottom".equals(anchorType) ? Gravity.BOTTOM : Gravity.TOP;
    }

    ad.show();
    result.success(Boolean.TRUE);
  }

  private void callIsAdLoaded(String adPlatform,Integer id, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("no_ad_for_id", "isAdLoaded failed, no add exists for id=" + id, null);
      return;
    }
    result.success(ad.status == MobileAd.Status.LOADED ? Boolean.TRUE : Boolean.FALSE);
  }

  private void callShowRewardedVideoAd(String adPlatform,Result result) {

    if(adPlatform.equalsIgnoreCase(AdPlatformEnum.qsj.name())){
      if (rewardedWrapper.getStatus() == QsjRewardedVideoAdWrapper.Status.LOADED) {
        rewardedWrapper.show();
        result.success(Boolean.TRUE);
      } else {
        result.error("ad_not_loaded", "show failed for rewarded video, no ad was loaded", null);
      }
    }else if(adPlatform.equalsIgnoreCase(AdPlatformEnum.tx.name())) {

      if (txRewardedVideoAdWrapper.getStatus() == TxRewardedVideoAdWrapper.Status.LOADED) {
        txRewardedVideoAdWrapper.show();
        result.success(Boolean.TRUE);
      } else {
        result.error("ad_not_loaded", "show failed for rewarded video, no ad was loaded", null);
      }

    }else {
      result.error("load_failed_ad", "cannot supported ad platform" , null);
      result.success(Boolean.FALSE);
      return;

    }

  }

  private void callDisposeAd(Integer id, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("no_ad_for_id", "dispose failed, no add exists for id=" + id, null);
      return;
    }

    ad.dispose();
    result.success(Boolean.TRUE);
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {

    Activity activity = registrar.activity();
    if (activity == null) {
      result.error("no_activity", "firebase_admob plugin requires a foreground activity", null);
      return;
    }

    Integer id = call.argument("id");

    String adPlatform = call.argument("adPlatform");

    switch (call.method) {
      case "initialize":
        callInitialize(call, result);
        break;
      case "loadBannerAd":
        callLoadBannerAd(adPlatform,id, activity, call, result);
        break;
      case "loadInterstitialAd":
        callLoadInterstitialAd(adPlatform,QsjMobileAd.createInterstitial(id, activity, channel), call, result);
        break;
      case "loadRewardedVideoAd":
        callLoadRewardedVideoAd(adPlatform,call, result);
        break;
      case "showAd":
        callShowAd(adPlatform,id, call, result);
        break;
      case "showRewardedVideoAd":
        callShowRewardedVideoAd(adPlatform,result);
        break;
      case "disposeAd":
        callDisposeAd(id, result);
        break;
      case "isAdLoaded":
        callIsAdLoaded(adPlatform,id, result);
        break;
      default:
        result.notImplemented();
    }
  }
}

==> qpc_admob-0.0.9%2B6.tar.gz: android/src/main/java/com/qpc/qpc_admob/QpcAdmobPlugin.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.app.Activity;
import android.view.Gravity;

import com.bytedance.sdk.openadsdk.TTAdConfig;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdSdk;

import java.util.Locale;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

public class QpcAdmobPlugin implements MethodCallHandler {

  private final Registrar registrar;
  private final MethodChannel channel;

  QsjRewardedVideoAdWrapper rewardedWrapper;

  TxRewardedVideoAdWrapper txRewardedVideoAdWrapper;

  public static void registerWith(Registrar registrar) {
    if (registrar.activity() == null) {
      // If a background Flutter view tries to register the plugin, there will be no activity from the registrar.
      // We stop the registering process immediately because the firebase_admob requires an activity.
      return;
    }
    final MethodChannel channel =
        new MethodChannel(registrar.messenger(), "com.qpc/qpc_admob");
    channel.setMethodCallHandler(new QpcAdmobPlugin(registrar, channel));

  }

  private QpcAdmobPlugin(Registrar registrar, MethodChannel channel) {
    this.registrar = registrar;
    this.channel = channel;


  }

  private void callInitialize(MethodCall call, Result result) {
    String appId = call.argument("appId");
    if (appId == null || appId.isEmpty()) {
      result.error("no_app_id", "a null or empty AdMob appId was provided", null);
      return;
    }

    Boolean isDebug = call.argument("isDebug");
    if(isDebug == null)


    {
      isDebug = false;
    }

    TTAdSdk.init(registrar.context(),
            new TTAdConfig.Builder()
                    .appId(appId)//测试"5001121"
                    .useTextureView(false) //使用TextureView控件播放视频,默认为SurfaceView,当有SurfaceView冲突的场景，可以使用TextureView
                    .appName("qkl")
                    .titleBarTheme(TTAdConstant.TITLE_BAR_THEME_DARK)
                    .allowShowNotify(true) //是否允许sdk展示通知栏提示
                    .allowShowPageWhenScreenLock(true) //是否在锁屏场景支持展示广告落地页
                    .debug(isDebug) //测试阶段打开，可以通过日志排查问题，上线时去除该调用
                    .directDownloadNetworkType(TTAdConstant.NETWORK_STATE_WIFI, TTAdConstant.NETWORK_STATE_3G) //允许直接下载的网络状态集合
                    .supportMultiProcess(false) //是否支持多进程，true支持
                    //.httpStack(new MyOkStack3())//自定义网络库，demo中给出了okhttp3版本的样例，其余请自行开发或者咨询工作人员。
                    .build());
    result.success(Boolean.TRUE);
  }

  private void callLoadBannerAd(String adPlatform,Integer id, Activity activity, MethodCall call, Result result) {
    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error("no_unit_id", "a null or empty adUnitId was provided for ad id=" + id, null);
      return;
    }

    final Integer width = call.argument("width");
    final Integer height = call.argument("height");
    final String adSizeType = call.argument("adSizeType");

    if (!"AdSizeType.WidthAndHeight".equals(adSizeType)
        && !"AdSizeType.SmartBanner".equals(adSizeType)) {
      String errMsg =
          String.format(
              Locale.ENGLISH,
              "an invalid adSizeType (%s) was provided for banner id=%d",
              adSizeType,
              id);
      result.error("invalid_adsizetype", errMsg, null);
    }

    if ("AdSizeType.WidthAndHeight".equals(adSizeType) && (width <= 0 || height <= 0)) {
      String errMsg =
          String.format(
              Locale.ENGLISH,
              "an invalid AdSize (%d, %d) was provided for banner id=%d",
              width,
              height,
              id);
      result.error("invalid_adsize", errMsg, null);
    }

    Map<String, Object> targetingInfo = call.argument("targetingInfo");

    MobileAd bannerAd= null;
    if(adPlatform.equalsIgnoreCase(AdPlatformEnum.qsj.name())){
      bannerAd  = QsjMobileAd.createBanner(id,adUnitId, width,height, activity, channel);
    }else if(adPlatform.equalsIgnoreCase(AdPlatformEnum.tx.name())) {
      bannerAd  = TxMobileAd.createBanner(id,adUnitId, width,height, activity, channel);
    }else {
      result.error("load_failed_ad", "cannot supported ad platform, id=" + id, null);
      result.success(Boolean.FALSE);
      return;

    }
    if (bannerAd.status != MobileAd.Status.CREATED) {
      if (bannerAd.status == MobileAd.Status.FAILED)
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + id, null);
      else result.success(Boolean.TRUE); // The ad was already loaded.
      return;
    }
    result.success(Boolean.TRUE);
  }

  private void callLoadInterstitialAd(String adPlatform,MobileAd ad, MethodCall call, Result result) {
    if (ad.status != MobileAd.Status.CREATED) {
      if (ad.status == MobileAd.Status.FAILED)
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + ad.id, null);
      else result.success(Boolean.TRUE); // The ad was already loaded.
      return;
    }

    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error(
          "no_adunit_id", "a null or empty adUnitId was provided for ad id=" + ad.id, null);
      return;
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    ad.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }

  private void callLoadRewardedVideoAd(String adPlatform,MethodCall call, Result result) {

    String adUnitId = call.argument("adUnitId");
    String userId = call.argument("userId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error(
              "no_ad_unit_id", "a non-empty adUnitId was not provided for rewarded video", null);
      return;
    }

    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    if (targetingInfo == null) {
      result.error(
              "no_targeting_info", "a null targetingInfo object was provided for rewarded video", null);
      return;
    }

    if(adPlatform.equalsIgnoreCase(AdPlatformEnum.qsj.name())){
      rewardedWrapper = new QsjRewardedVideoAdWrapper(registrar.activity(), channel);
      callLoadQsjRewardedVideoAd(adUnitId, userId, targetingInfo,result);
    }else if(adPlatform.equalsIgnoreCase(AdPlatformEnum.tx.name())) {
      txRewardedVideoAdWrapper = new TxRewardedVideoAdWrapper(registrar.activity(),channel);
      txRewardedVideoAdWrapper.load(adUnitId,userId,targetingInfo);
    }else {
      result.error("load_failed_ad", "cannot supported ad platform, adUnitId=" + adUnitId, null);
      result.success(Boolean.FALSE);
      return;

    }
  }

  private void callLoadQsjRewardedVideoAd(String adUnitId, String userId, Map<String, Object> targetingInfo,Result result) {
    if (rewardedWrapper.getStatus() != RewardVideoStatus.CREATED
        && rewardedWrapper.getStatus() != RewardVideoStatus.FAILED) {
      result.success(Boolean.TRUE); // The ad was already loading or loaded.
      return;
    }
    rewardedWrapper.load(adUnitId,userId, targetingInfo);
    result.success(Boolean.TRUE);
  }

  private void callShowAd(String adPlatform,Integer id, MethodCall call, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("ad_not_loaded", "show failed, the specified ad was not loaded id=" + id, null);
      return;
    }
    final String anchorOffset = call.argument("anchorOffset");
    final String horizontalCenterOffset = call.argument("horizontalCenterOffset");
    final String anchorType = call.argument("anchorType");
    if (anchorOffset != null) {
      ad.anchorOffset = Double.parseDouble(anchorOffset);
    }
    if (anchorType != null) {
      ad.horizontalCenterOffset = Double.parseDouble(horizontalCenterOffset);
    }
    if (anchorType != null) {
      ad.anchorType = "bottom".equals(anchorType) ? Gravity.BOTTOM : Gravity.TOP;
    }

    ad.show();
    result.success(Boolean.TRUE);
  }

  private void callIsAdLoaded(String adPlatform,Integer id, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("no_ad_for_id", "isAdLoaded failed, no add exists for id=" + id, null);
      return;
    }
    result.success(ad.status == MobileAd.Status.LOADED ? Boolean.TRUE : Boolean.FALSE);
  }

  private void callShowRewardedVideoAd(String adPlatform,Result result) {

    if(adPlatform.equalsIgnoreCase(AdPlatformEnum.qsj.name())){
      if (rewardedWrapper.getStatus() == RewardVideoStatus.LOADED) {
        rewardedWrapper.show();
        result.success(Boolean.TRUE);
      } else {
        result.error("ad_not_loaded", "show failed for rewarded video, no ad was loaded", null);
      }
    }else if(adPlatform.equalsIgnoreCase(AdPlatformEnum.tx.name())) {

      if (txRewardedVideoAdWrapper.getStatus() == RewardVideoStatus.LOADED) {
        txRewardedVideoAdWrapper.show();
        result.success(Boolean.TRUE);
      } else {
        result.error("ad_not_loaded", "show failed for rewarded video, no ad was loaded", null);
      }

    }else {
      result.error("load_failed_ad", "cannot supported ad platform" , null);
      result.success(Boolean.FALSE);
      return;

    }

  }

  private void callDisposeAd(Integer id, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("no_ad_for_id", "dispose failed, no add exists for id=" + id, null);
      return;
    }

    ad.dispose();
    result.success(Boolean.TRUE);
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {

    Activity activity = registrar.activity();
    if (activity == null) {
      result.error("no_activity", "firebase_admob plugin requires a foreground activity", null);
      return;
    }

    Integer id = call.argument("id");

    String adPlatform = call.argument("adPlatform");

    switch (call.method) {
      case "initialize":
        callInitialize(call, result);
        break;
      case "loadBannerAd":
        callLoadBannerAd(adPlatform,id, activity, call, result);
        break;
      case "loadInterstitialAd":
        callLoadInterstitialAd(adPlatform,QsjMobileAd.createInterstitial(id, activity, channel), call, result);
        break;
      case "loadRewardedVideoAd":
        callLoadRewardedVideoAd(adPlatform,call, result);
        break;
      case "showAd":
        callShowAd(adPlatform,id, call, result);
        break;
      case "showRewardedVideoAd":
        callShowRewardedVideoAd(adPlatform,result);
        break;
      case "disposeAd":
        callDisposeAd(id, result);
        break;
      case "isAdLoaded":
        callIsAdLoaded(adPlatform,id, result);
        break;
      default:
        result.notImplemented();
    }
  }
}
